@@ -1,11 +1,11 @@
 import copy
+
 import numpy as np
-from scipy.optimize import curve_fit
+from openmdao.api import Group, ExplicitComponent
 from scipy.interpolate import PchipInterpolator
-from openmdao.api import ExplicitComponent, Group
-from wisdem.commonse.utilities import rotate, arc_length
-from wisdem.rotorse.precomp import PreComp, Profile, Orthotropic2DMaterial, CompositeSection
+from wisdem.rotorse.precomp import PreComp, Profile, CompositeSection, Orthotropic2DMaterial
 from wisdem.commonse.csystem import DirectionVector
+from wisdem.commonse.utilities import rotate, arc_length
 from wisdem.rotorse.rotor_cost import blade_cost_model
 from wisdem.rotorse.rail_transport import RailTransport
 
@@ -17,7 +17,7 @@ class RunPreComp(ExplicitComponent):
         self.options.declare("opt_options")
 
     def setup(self):
-        rotorse_options = self.options["modeling_options"]["RotorSE"]
+        rotorse_options = self.options["modeling_options"]["WISDEM"]["RotorSE"]
         self.n_span = n_span = rotorse_options["n_span"]
         self.n_webs = n_webs = rotorse_options["n_webs"]
         self.n_layers = n_layers = rotorse_options["n_layers"]
@@ -500,8 +500,8 @@ class RunPreComp(ExplicitComponent):
             return sec
             ##############################
 
-        layer_name = self.options["modeling_options"]["RotorSE"]["layer_name"]
-        layer_mat = self.options["modeling_options"]["RotorSE"]["layer_mat"]
+        layer_name = self.options["modeling_options"]["WISDEM"]["RotorSE"]["layer_name"]
+        layer_mat = self.options["modeling_options"]["WISDEM"]["RotorSE"]["layer_mat"]
 
         upperCS = [None] * self.n_span
         lowerCS = [None] * self.n_span
