@@ -1,6 +1,7 @@
+import unittest
+
 import numpy as np
 import numpy.testing as npt
-import unittest
 from wisdem.commonse.cross_sections import Tube, CylindricalShellProperties
 
 npts = 100
@@ -43,4 +44,9 @@ def suite():
 
 
 if __name__ == "__main__":
-    unittest.TextTestRunner().run(suite())
+    result = unittest.TextTestRunner().run(suite())
+
+    if result.wasSuccessful():
+        exit(0)
+    else:
+        exit(1)
