@@ -117,8 +117,8 @@ class TestGenerators(unittest.TestCase):
         self.assertAlmostEqual(self.outputs["A_Cuscalc"], 389.46615218)
         self.assertAlmostEqual(self.outputs["J_actual"][-1], 3.125519048273891)
         self.assertAlmostEqual(self.outputs["A_1"][-1], 148362.95007673657)
-        self.assertAlmostEqual(len(self.outputs["generator_efficiency"]), 20)
-        self.assertAlmostEqual(self.outputs["generator_efficiency"][-1], 0.9543687904168252)
+        self.assertAlmostEqual(len(self.outputs["eandm_efficiency"]), 20)
+        self.assertAlmostEqual(self.outputs["eandm_efficiency"][-1], 0.9543687904168252)
         self.assertAlmostEqual(self.outputs["Iron"], 89073.14254723)
         self.assertAlmostEqual(self.outputs["mass_PM"], 1274.81620149)
         self.assertAlmostEqual(self.outputs["Copper"], 13859.17179278)
@@ -173,8 +173,8 @@ class TestGenerators(unittest.TestCase):
         self.assertAlmostEqual(self.outputs["J_s"][-1], 3.337574160500578)
         self.assertAlmostEqual(self.outputs["Losses"][-1], 351360.55854497873)
         self.assertAlmostEqual(self.outputs["K_rad"], 0.245398773006135)
-        self.assertAlmostEqual(len(self.outputs["generator_efficiency"]), 20)
-        self.assertAlmostEqual(self.outputs["generator_efficiency"][-1], 0.9343418267745142)
+        self.assertAlmostEqual(len(self.outputs["eandm_efficiency"]), 20)
+        self.assertAlmostEqual(self.outputs["eandm_efficiency"][-1], 0.9343418267745142)
         self.assertAlmostEqual(self.outputs["S"], 768.0)
         self.assertAlmostEqual(self.outputs["Slot_aspect_ratio"], 5.832426544390113)
         self.assertAlmostEqual(self.outputs["Copper"], 6654.6915566955695)
@@ -227,8 +227,8 @@ class TestGenerators(unittest.TestCase):
         self.assertAlmostEqual(self.outputs["J_s"][-1], 3.5129208)
         self.assertAlmostEqual(self.outputs["Losses"][-1], 338164.5549178)
         self.assertAlmostEqual(self.outputs["K_rad"], 0.2148997)
-        self.assertAlmostEqual(len(self.outputs["generator_efficiency"]), 20)
-        self.assertAlmostEqual(self.outputs["generator_efficiency"][-1], 0.936651530)
+        self.assertAlmostEqual(len(self.outputs["eandm_efficiency"]), 20)
+        self.assertAlmostEqual(self.outputs["eandm_efficiency"][-1], 0.936651530)
         self.assertAlmostEqual(self.outputs["S"], 942.0000000)
         self.assertAlmostEqual(self.outputs["Slot_aspect_ratio"], 5.7277538)
         self.assertAlmostEqual(self.outputs["Copper"], 5588.6107806)
@@ -280,8 +280,8 @@ class TestGenerators(unittest.TestCase):
         self.assertAlmostEqual(self.outputs["J_s"][-1], 3.75697924800609)
         self.assertAlmostEqual(self.outputs["Losses"][-1], 444556.7203870894)
         self.assertAlmostEqual(self.outputs["K_rad"], 0.21874999999999997)
-        self.assertAlmostEqual(len(self.outputs["generator_efficiency"]), 20)
-        self.assertAlmostEqual(self.outputs["generator_efficiency"][-1], 0.918348408655116)
+        self.assertAlmostEqual(len(self.outputs["eandm_efficiency"]), 20)
+        self.assertAlmostEqual(self.outputs["eandm_efficiency"][-1], 0.918348408655116)
         self.assertAlmostEqual(self.outputs["S"], 708.0)
         self.assertAlmostEqual(self.outputs["Slot_aspect_ratio"], 4.695070821210912)
         self.assertAlmostEqual(self.outputs["Copper"], 16059.414075335235)
@@ -341,10 +341,11 @@ class TestGenerators(unittest.TestCase):
         self.assertAlmostEqual(self.outputs["generator_mass"], 40729.31598698678)
         self.assertAlmostEqual(self.outputs["K_rad"], 1.1818181818181817)
         self.assertAlmostEqual(self.outputs["Losses"][-1], 75068.46569051298)
-        self.assertAlmostEqual(len(self.outputs["generator_efficiency"]), 20)
-        self.assertAlmostEqual(self.outputs["generator_efficiency"][-1], 0.9849562794756211)
+        self.assertAlmostEqual(len(self.outputs["eandm_efficiency"]), 20)
+        self.assertAlmostEqual(self.outputs["eandm_efficiency"][-1], 0.9849562794756211)
         self.assertAlmostEqual(self.outputs["Copper"], 1360.253987369221)
         self.assertAlmostEqual(self.outputs["Iron"], 11520.904698026085)
+        self.assertAlmostEqual(self.outputs["R_out"], 0.7663579416108941)
         self.assertAlmostEqual(self.outputs["Structural_mass"], 27848.15730159148)
         self.assertAlmostEqual(self.outputs["TC1"], 0.29453832454167966)
 
@@ -402,11 +403,12 @@ class TestGenerators(unittest.TestCase):
         self.assertAlmostEqual(self.outputs["generator_mass"], 19508.405570203206)
         self.assertAlmostEqual(self.outputs["K_rad"], 0.4016393442622951)
         self.assertAlmostEqual(self.outputs["Losses"][-1], 143901.77088462992)
-        self.assertAlmostEqual(len(self.outputs["generator_efficiency"]), 20)
-        self.assertAlmostEqual(self.outputs["generator_efficiency"][-1], 0.9654635749876888)
+        self.assertAlmostEqual(len(self.outputs["eandm_efficiency"]), 20)
+        self.assertAlmostEqual(self.outputs["eandm_efficiency"][-1], 0.9654635749876888)
         self.assertAlmostEqual(self.outputs["Copper"], 354.97950026786026)
         self.assertAlmostEqual(self.outputs["Iron"], 6077.944572132577)
         self.assertAlmostEqual(self.outputs["Structural_mass"], 13075.48149780277)
+        self.assertAlmostEqual(self.outputs["R_out"], 0.8681961572673457)
         self.assertAlmostEqual(self.outputs["TC1"], 0.24790308982258036)
         self.assertAlmostEqual(self.outputs["Current_ratio"][-1], 0.17760183748148742)
 
